Struct googapis::google::cloud::aiplatform::v1::ModelEvaluationSlice[][src]

pub struct ModelEvaluationSlice {
    pub name: String,
    pub slice: Option<Slice>,
    pub metrics_schema_uri: String,
    pub metrics: Option<Value>,
    pub create_time: Option<Timestamp>,
}
A collection of metrics calculated by comparing Model’s predictions on a slice of the test data against ground truth annotations.

Fields

name: String

Output only. The resource name of the ModelEvaluationSlice.

slice: Option<Slice>

Output only. The slice of the test data that is used to evaluate the Model.

metrics_schema_uri: String

Output only. Points to a YAML file stored on Google Cloud Storage describing the [metrics][google.cloud.aiplatform.v1.ModelEvaluationSlice.metrics] of this ModelEvaluationSlice. The schema is defined as an OpenAPI 3.0.2 Schema Object.

metrics: Option<Value>

Output only. Sliced evaluation metrics of the Model. The schema of the metrics is stored in [metrics_schema_uri][google.cloud.aiplatform.v1.ModelEvaluationSlice.metrics_schema_uri]

create_time: Option<Timestamp>

Output only. Timestamp when this ModelEvaluationSlice was created.